@@ -24,7 +24,9 @@ __all__ = (
 
     'DEFAULT_MAX_LENGTH', 'FORM_HANDLER_PLUGINS_EXECUTION_ORDER',
     'FAIL_ON_MISSING_FORM_ELEMENT_PLUGINS',
-    'FAIL_ON_MISSING_FORM_HANDLER_PLUGINS'
+    'FAIL_ON_MISSING_FORM_HANDLER_PLUGINS',
+    'FAIL_ON_ERRORS_IN_FORM_ELEMENT_PLUGINS',
+    'FAIL_ON_ERRORS_IN_FORM_HANDLER_PLUGINS',
 
     'WAIT_BETWEEN_TEST_STEPS', 'WAIT_AT_TEST_END',
 )
@@ -85,6 +87,12 @@ FAIL_ON_MISSING_FORM_ELEMENT_PLUGINS = \
 FAIL_ON_MISSING_FORM_HANDLER_PLUGINS = \
     get_setting('FAIL_ON_MISSING_FORM_HANDLER_PLUGINS')
 
+FAIL_ON_ERRORS_IN_FORM_ELEMENT_PLUGINS = \
+    get_setting('FAIL_ON_ERRORS_IN_FORM_ELEMENT_PLUGINS')
+
+FAIL_ON_ERRORS_IN_FORM_HANDLER_PLUGINS = \
+    get_setting('FAIL_ON_ERRORS_IN_FORM_HANDLER_PLUGINS')
+
 # **************************************************************
 # **************************************************************
 # ************************ Tests related ***********************
